@@ -27,9 +27,21 @@ sub process {
     if($data->{'service'} && ref($data->{'service'}) eq 'ServiceType'){
         $service = $data->{'service'};
     } elsif($data->{'protocol'} || $data->{'portlist'}) {
-        $service = ServiceType->new();
+        if($data->{'service'}){
+            my $app = SoftwareType->new({
+                name    => $data->{'service'},
+            });
+            $service = ServiceType->new({
+                Application => $app,
+            });
+        } else {
+            $service = ServiceType->new();
+        }
         my $proto = $data->{'protocol'} || $data->{'ip_protocol'};
         if($data->{'portlist'}){
+            # normalize peoples wierd port habbits
+            $data->{'portlist'} =~ m/(\d+(-\d+)?)$/;
+            $data->{'portlist'} = $1;
             $service->set_Portlist($data->{'portlist'});
             # IODEF requires a default
             $proto = 'tcp' unless($proto);
@@ -54,9 +66,10 @@ sub process {
     if($data->{'rdata'}){
         $system->set_AdditionalData(
             ExtensionType->new({
-                dtype   => ExtensionType::DtypeType::dtype_type_string(),
-                meaning => 'rdata',
-                content => $data->{'rdata'},
+                dtype       => ExtensionType::DtypeType::dtype_type_string(),
+                meaning     => 'rdata',
+                formatid    => $data->{'rdata_type'} || 'A',
+                content     => $data->{'rdata'},
             })
         );
     }
