@@ -4,6 +4,8 @@ use base 'Iodef::Pb::Simple::Plugin';
 use strict;
 use warnings;
 
+use Iodef::Pb::Simple qw/is_uuid uuid_ns/;
+
 sub process {
     my $self = shift;
     my $data = shift;
@@ -11,6 +13,8 @@ sub process {
     
     return unless($data->{'guid'});
     
+    $data->{'guid'} = uuid_ns($data->{'guid'}) unless(is_uuid($data->{'guid'}));
+    
     my $ad = ExtensionType->new({
         dtype       => ExtensionType::DtypeType::dtype_type_string(),
         content     => $data->{'guid'},
