@@ -13,10 +13,12 @@ sub process {
     my $iodef = shift;
     
     my $addr = $data->{'address'};
-    return unless($addr && $addr =~ /^$RE{'net'}{'IPv4'}/);
+    return unless($addr && ($addr =~ /^$RE{'net'}{'IPv4'}$/ || $addr =~ /^$RE{'net'}{'CIDR'}{'IPv4'}$/));
     
     my $category = ($addr =~ /^$RE{'net'}{'IPv4'}$/) ? AddressType::AddressCategory::Address_category_ipv4_addr() : AddressType::AddressCategory::Address_category_ipv4_net();
     
+    $addr = normalize_address($addr);
+    
     my @additional_data;
     if($data->{'prefix'} && $data->{'prefix'} =~ /^$RE{'net'}{'CIDR'}{'IPv4'}$/){
         push(@additional_data,ExtensionType->new({
@@ -122,4 +124,20 @@ sub process {
     push(@{$incident->{'EventData'}},$event);
 }
 
+sub normalize_address {
+    my $addr = shift;
+
+    my @bits = split(/\./,$addr);
+    foreach(@bits){
+        if(/^0+\/(\d+)$/){
+            $_ = '0/'.$1;
+        } else {
+            next if(/^0$/);
+            next unless(/^0{1,2}/);
+            $_ =~ s/^0{1,2}//;
+        }
+    }
+    return join('.',@bits);
+}
+
 1;
\ No newline at end of file
