@@ -10,11 +10,10 @@ sub process {
     my $iodef = shift;
       
     my $dt = $data->{'reporttime'};
-    # default it to the hour
     unless($dt){
         require DateTime;
         $dt = DateTime->from_epoch(epoch => time());
-        $dt = $dt->ymd().'T'.$dt->hour().':00:00Z';
+        $dt = $dt->ymd().'T'.$dt->hms().'Z';
     }
     unless(ref($dt) eq 'DateTime'){
         $dt = $self->SUPER::normalize_timestamp($dt);
